summaryrefslogtreecommitdiff
path: root/wizards/com/sun/star/wizards/text
diff options
context:
space:
mode:
authorRĂ¼diger Timm <rt@openoffice.org>2005-11-11 11:19:55 +0000
committerRĂ¼diger Timm <rt@openoffice.org>2005-11-11 11:19:55 +0000
commit6d448608b0f3f8bc387b678c4a3e617f20a60463 (patch)
tree77928b0296b66aeb81fa5d936311a1516df39c50 /wizards/com/sun/star/wizards/text
parentd806c21529d49b968b97ace5ded17cc86e909058 (diff)
INTEGRATION: CWS c06 (1.7.90); FILE MERGED
2005/09/15 11:53:26 tv 1.7.90.1: #53536# make sure wizards with live previews behave correctly in terms of attaching and removing a termination listener and being openend via dispatch rather than loadComponentFromURL
Diffstat (limited to 'wizards/com/sun/star/wizards/text')
-rw-r--r--wizards/com/sun/star/wizards/text/TextDocument.java15
1 files changed, 10 insertions, 5 deletions
diff --git a/wizards/com/sun/star/wizards/text/TextDocument.java b/wizards/com/sun/star/wizards/text/TextDocument.java
index 5a87b8d540c3..4189ef3b6f68 100644
--- a/wizards/com/sun/star/wizards/text/TextDocument.java
+++ b/wizards/com/sun/star/wizards/text/TextDocument.java
@@ -4,9 +4,9 @@
*
* $RCSfile: TextDocument.java,v $
*
- * $Revision: 1.8 $
+ * $Revision: 1.9 $
*
- * last change: $Author: rt $ $Date: 2005-09-09 09:41:56 $
+ * last change: $Author: rt $ $Date: 2005-11-11 12:19:55 $
*
* The Contents of this file are made available subject to
* the terms of GNU Lesser General Public License Version 2.1.
@@ -99,13 +99,18 @@ public class TextDocument {
public com.sun.star.lang.Locale CharLocale;
public XStorable xStorable;
//creates an instance of TextDocument and creates a frame
public TextDocument(XMultiServiceFactory xMSF, XTerminateListener listener) {
+ this(xMSF, listener, "_blank");
+ }
+
+// creates an instance of TextDocument and creates a named frame
+ public TextDocument(XMultiServiceFactory xMSF, XTerminateListener listener, String FrameName) {
this.xMSF = xMSF;
- XDesktop xDesktop = Desktop.getDesktop(xMSF);
- xFrame = OfficeDocument.createNewFrame(xMSF, listener);
+ xFrame = OfficeDocument.createNewFrame(xMSF, listener, FrameName);
}
+
//creates an instance of TextDocument and creates a frame with an empty document
public TextDocument(XMultiServiceFactory xMSF, boolean bshowStatusIndicator, boolean bgetCurrentFrame, XTerminateListener listener) {
this.xMSF = xMSF;
@@ -99,13 +99,18 @@ public class TextDocument {
public com.sun.star.lang.Locale CharLocale;
public XStorable xStorable;
- //creates an instance of TextDocument and creates a frame
+ //creates an instance of TextDocument and creates a blank frame
public TextDocument(XMultiServiceFactory xMSF, XTerminateListener listener) {